@@ -35,8 +35,6 @@
  */
 
 #include <string.h>
-#include <libxml/parser.h>
-#include <libxml/tree.h>
 
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-marshal.h>
