@@ -257,9 +257,46 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
 
 /* VOID:POINTER (./libanjuta-iface-marshallers.list:10) */
 
-/* VOID:STRING (./libanjuta-iface-marshallers.list:11) */
+/* VOID:POINTER,BOXED (./libanjuta-iface-marshallers.list:11) */
+void
+libanjuta_iface_cclosure_marshal_VOID__POINTER_BOXED (GClosure     *closure,
+                                                      GValue       *return_value G_GNUC_UNUSED,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint G_GNUC_UNUSED,
+                                                      gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__POINTER_BOXED) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     arg_2,
+                                                    gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
 
-/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:12) */
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__POINTER_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_pointer (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 2),
+            data2);
+}
+
+/* VOID:STRING (./libanjuta-iface-marshallers.list:12) */
+
+/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:13) */
 void
 libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                       GValue       *return_value G_GNUC_UNUSED,
@@ -296,7 +333,7 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:13) */
+/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:14) */
 void
 libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                  GValue       *return_value G_GNUC_UNUSED,
@@ -333,7 +370,7 @@ libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:14) */
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:15) */
 void
 libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                           GValue       *return_value G_GNUC_UNUSED,
@@ -372,5 +409,5 @@ libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:15) */
+/* VOID:VOID (./libanjuta-iface-marshallers.list:16) */
 
