@@ -45,7 +45,7 @@ git_add_command_finalize (GObject *object)
 	
 	self = GIT_ADD_COMMAND (object);
 	
-	git_command_free_path_list (self->priv->paths);
+	git_command_free_string_list (self->priv->paths);
 	g_free (self->priv);
 
 	G_OBJECT_CLASS (git_add_command_parent_class)->finalize (object);
@@ -106,7 +106,7 @@ git_add_command_new_list (const gchar *working_directory, GList *path_list,
 						 "working-directory", working_directory,
 						 NULL);
 	
-	self->priv->paths = git_command_copy_path_list (path_list);
+	self->priv->paths = git_command_copy_string_list (path_list);
 	self->priv->force = force;
 	
 	return self;
