@@ -220,9 +220,8 @@ git_command_launch (GitCommand *self)
 	else
 		callback = (AnjutaLauncherOutputCallback) git_command_multi_line_output_arrived;
 
-	chdir (self->priv->working_directory);
-	
-	if (!anjuta_launcher_execute_v (self->priv->launcher, 
+	if (!anjuta_launcher_execute_v (self->priv->launcher,
+	    							self->priv->working_directory,
 									args,
 									NULL,
 									callback,
@@ -317,6 +316,14 @@ git_command_error_handler (GitCommand *self, const gchar *output)
 	}
 }
 
+static void
+git_command_clear_args_list (GitCommand *self)
+{
+	g_list_foreach (self->priv->args, (GFunc) g_free, NULL);
+	g_list_free (self->priv->args);
+	self->priv->args = NULL;
+}
+
 static void
 git_command_child_exited (AnjutaLauncher *launcher, gint child_pid, gint status, 
 						  gulong time, GitCommand *self)
@@ -326,6 +333,9 @@ git_command_child_exited (AnjutaLauncher *launcher, gint child_pid, gint status,
 		anjuta_command_set_error_message (ANJUTA_COMMAND (self),
 										  self->priv->error_string->str);
 	}
+
+	/* Clear the argument list to make the command reusable */
+	git_command_clear_args_list (self);
 	
 	anjuta_command_notify_complete (ANJUTA_COMMAND (self), 
 									(guint) WEXITSTATUS (status));
@@ -353,18 +363,11 @@ static void
 git_command_finalize (GObject *object)
 {
 	GitCommand *self;
-	GList *current_arg;
 	GList *current_info;
 	
 	self = GIT_COMMAND (object);
 	
-	current_arg = self->priv->args;
-	
-	while (current_arg)
-	{
-		g_free (current_arg->data);
-		current_arg = g_list_next (current_arg);
-	}
+	git_command_clear_args_list (self);
 	
 	current_info = self->priv->info_queue->head;
 	
@@ -449,7 +452,7 @@ git_command_class_init (GitCommandClass *klass)
 														  "",
 														  "Directory to run git in.",
 														  "",
-														  G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+														  G_PARAM_READWRITE));
 	
 	g_object_class_install_property (object_class, PROP_SINGLE_LINE_OUTPUT,
 									 g_param_spec_boolean ("single-line-output",
@@ -538,7 +541,7 @@ git_command_send_output_to_info (GitCommand *git_command, const gchar *output)
 }
 
 GList *
-git_command_copy_path_list (GList *list)
+git_command_copy_string_list (GList *list)
 {
 	GList *current_path;
 	GList *new_list;
@@ -556,7 +559,7 @@ git_command_copy_path_list (GList *list)
 }
 
 void
-git_command_free_path_list (GList *list)
+git_command_free_string_list (GList *list)
 {
 	GList *current_path;
 	
