@@ -45,7 +45,13 @@
 typedef struct _PropertiesTable
 {
 	AnjutaPmProject *project;
+	GtkWidget *dialog;
 	GtkWidget *table;
+	GtkWidget *head;
+	GtkWidget *main;
+	GtkWidget *expand;
+	GtkWidget *extra;
+	GbfTreeData *data;
 	AnjutaProjectNode *node;
 	GList *properties;
 } PropertiesTable;
@@ -383,6 +389,7 @@ add_entry (IAnjutaProject *project, AnjutaProjectNode *node, AnjutaProjectProper
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GList *item;
+	gchar *tooltip = NULL;
 
 	if (prop->native != NULL)
 	{
@@ -392,6 +399,23 @@ add_entry (IAnjutaProject *project, AnjutaProjectNode *node, AnjutaProjectProper
 	{
 		label = gtk_label_new (_(prop->name));
 	}
+
+	if (prop->detail != NULL)
+	{
+		if (prop->flags & ANJUTA_PROJECT_PROPERTY_READ_ONLY)
+		{
+			tooltip = g_strconcat (_(prop->detail), _(" This property is not modifiable."), NULL);
+		}
+		else
+		{
+			tooltip = g_strdup (_(prop->detail));
+		}
+	}
+	
+	if (tooltip != NULL)
+	{
+		gtk_widget_set_tooltip_markup (label, tooltip);
+	}
 	gtk_misc_set_alignment (GTK_MISC (label), 0, -1);
 	gtk_widget_show (label);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, *position, *position+1,
@@ -458,6 +482,12 @@ add_entry (IAnjutaProject *project, AnjutaProjectNode *node, AnjutaProjectProper
 	default:
 		return NULL;
 	}		
+	if (tooltip != NULL)
+	{
+		gtk_widget_set_tooltip_markup (entry, tooltip);
+	}
+	g_free (tooltip);
+	
 	gtk_widget_show (entry);
 	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, *position, *position+1,
 			  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
@@ -487,60 +517,100 @@ add_label (const gchar *display_name, const gchar *value, GtkWidget *table, gint
 	*position = *position + 1;
 }
 
-static PropertiesTable*
-create_properties_table (IAnjutaProject *project, AnjutaProjectNode *node)
+static gboolean
+is_project_node_but_shortcut (GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-	GtkBuilder *bxml;
-	PropertiesTable *table;
-	GtkWidget *properties;
-	GtkWidget *main_table;
-	GtkWidget *extra_table;
-	GtkWidget *extra_expand;
-	GFile *file;
+	GbfTreeData *data;
 
+	gtk_tree_model_get (GTK_TREE_MODEL (model), iter,
+		    GBF_PROJECT_MODEL_COLUMN_DATA, &data,
+		    -1);
+
+	return (data != NULL) && (data->shortcut == NULL) && (gbf_tree_data_get_node (data) != NULL);
+}
+
+static void
+update_properties (PropertiesTable *table)
+{
+	GFile *file;
+	const gchar *title;
+	gint head_pos;
 	gint main_pos;
 	gint extra_pos;
-	gchar *path;
 	const GList *item;
 	AnjutaProjectNodeType type;
 	AnjutaProjectNodeInfo* node_info;
 	gboolean single;
+	GList *children;
+	GList *last;
 
-	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
-	if (!bxml) return NULL;
-
-	table = g_new0 (PropertiesTable, 1);
-	table->node = node;
-	anjuta_util_builder_get_objects (bxml,
-									"properties", &properties,
-									"main_table", &main_table,
-									"extra_table", &extra_table,
-									"extra_expand", &extra_expand,
-									NULL);
-	table->table = properties;
-	g_object_ref (properties);
-
+	head_pos = 0;
 	main_pos = 0;
 	extra_pos = 0;
 
-	/* Always display node name */
-	file = anjuta_project_node_get_file (node);
+	/* Update dialog type */
+	switch (anjuta_project_node_get_node_type (table->node))
+	{
+	case ANJUTA_PROJECT_ROOT:
+		title = _("Project properties");
+		break;
+	case ANJUTA_PROJECT_GROUP:
+		title = _("Directory properties");
+		break;
+	case ANJUTA_PROJECT_TARGET:
+		title = _("Target properties");
+		break;
+	case ANJUTA_PROJECT_SOURCE:
+		title = _("Source properties");
+		break;
+	case ANJUTA_PROJECT_MODULE:
+		title = _("Module properties");
+		break;
+	case ANJUTA_PROJECT_PACKAGE:
+		title = _("Package properties");
+		break;
+	default:
+		title = _("Unknown properties");
+		break;
+	}
+	gtk_window_set_title (GTK_WINDOW (table->dialog), title);
+
+	/* Clear table */
+	children = gtk_container_get_children (GTK_CONTAINER (table->head));
+	/* Clear only the first 4 widgets */
+	while ((last = g_list_nth (children, 4)) != NULL) children = g_list_delete_link (children, last);
+	g_list_foreach (children, (GFunc)gtk_widget_destroy, NULL);
+	g_list_free (children);
+	children = gtk_container_get_children (GTK_CONTAINER (table->main));
+	g_list_foreach (children, (GFunc)gtk_widget_destroy, NULL);
+	g_list_free (children);
+	children = gtk_container_get_children (GTK_CONTAINER (table->extra));
+	g_list_foreach (children, (GFunc)gtk_widget_destroy, NULL);
+	g_list_free (children);
+	g_list_foreach (table->properties, (GFunc)pm_property_entry_free, NULL);
+	g_list_free (table->properties);
+	table->properties = NULL;
+	
+	/* Update node name */
+	file = anjuta_project_node_get_file (table->node);
 	if (file != NULL)
 	{
+		gchar *path;
+		
 		path = g_file_get_path (file);
-		add_label (_("Path:"), path, main_table, &main_pos);
+		add_label (_("Path:"), path, table->head, &head_pos);
 		g_free (path);
 	}
 	else
 	{
-		add_label (_("Name:"), anjuta_project_node_get_name (node), main_table, &main_pos);
+		add_label (_("Name:"), anjuta_project_node_get_name (table->node), table->head, &head_pos);
 	}
-
+	
 	/* Display node type only if several types are possible */
 	node_info = NULL;
 	single = TRUE;
-	type = anjuta_project_node_get_node_type (node);
-	for (item = ianjuta_project_get_node_info (project, NULL); item != NULL; item = g_list_next (item))
+	type = anjuta_project_node_get_full_type (table->node);
+	for (item = ianjuta_project_get_node_info (table->project->project, NULL); item != NULL; item = g_list_next (item))
 	{
 		AnjutaProjectNodeInfo* info = (AnjutaProjectNodeInfo *)item->data;
 
@@ -552,32 +622,31 @@ create_properties_table (IAnjutaProject *project, AnjutaProjectNode *node)
 		{
 			single = FALSE;
 		}
-		if (!single && (node_info != NULL))
-		{
-			add_label (_("Type:"), anjuta_project_node_info_name (node_info), main_table, &main_pos);
-			break;
-		}
+	}
+	if (!single && (node_info != NULL))
+	{
+		add_label (_("Type:"), anjuta_project_node_info_name (node_info), table->main, &main_pos);
 	}
 
 	/* Display other node properties */
 	single = FALSE;
 
-	for (item = anjuta_project_node_get_native_properties (node); item != NULL; item = g_list_next (item))
+	for (item = anjuta_project_node_get_native_properties (table->node); item != NULL; item = g_list_next (item))
 	{
 		AnjutaProjectProperty *valid_prop = (AnjutaProjectProperty *)item->data; 
 		AnjutaProjectProperty *prop; 
 		GtkWidget *entry;
 
-		prop = anjuta_project_node_get_property (node, valid_prop);
-		if (prop != NULL)
+		prop = anjuta_project_node_get_property (table->node, valid_prop);
+		if (prop->native != NULL)
 		{
 			/* This property has been set, display it in the main part */
-			entry = add_entry (project, node, prop, main_table, &main_pos);
+			entry = add_entry (table->project->project, table->node, prop, table->main, &main_pos);
 		}
 		else
 		{
 			/* This property has not been set, hide it by default */
-			entry = add_entry (project, node, valid_prop, extra_table, &extra_pos);
+			entry = add_entry (table->project->project, table->node, valid_prop, table->extra, &extra_pos);
 			single = TRUE;
 		}
 
@@ -588,14 +657,13 @@ create_properties_table (IAnjutaProject *project, AnjutaProjectNode *node)
 		}
 	}
 	table->properties = g_list_reverse (table->properties);
-	gtk_widget_show_all (properties);
+	gtk_widget_show_all (table->table);
 	
 	/* Hide expander if it is empty */
-	if (!single) gtk_widget_hide (extra_expand);
-	
-	g_object_unref (bxml);
-	
-	return table;
+	if (single)
+		gtk_widget_show (table->expand);
+	else
+		gtk_widget_hide (table->expand);
 }
 
 static void
@@ -663,73 +731,171 @@ on_properties_dialog_response (GtkWidget *dialog,
 	gtk_widget_destroy (dialog);
 }
 
+static void
+on_node_changed (GtkTreeView       *view,
+                 gpointer           user_data)     
+{
+	PropertiesTable *table = (PropertiesTable *)user_data;
+	GtkTreeIter iter;
+	GtkTreePath *path;
+	GtkTreeModel *model;
+
+	model = gtk_tree_view_get_model (view);
+	gtk_tree_view_get_cursor (view, &path, NULL);
+	
+	if (gtk_tree_model_get_iter (model, &iter, path))
+	{
+		GbfTreeData *data;
+		
+		gtk_tree_model_get (model, &iter, GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
+
+		if (table->data->properties_dialog != NULL)
+		{
+			g_object_remove_weak_pointer (G_OBJECT (table->dialog), (gpointer *)&table->data->properties_dialog);
+			table->data->properties_dialog = NULL;
+		}
+		if (data->properties_dialog != NULL)
+		{
+			g_object_unref (data->properties_dialog);
+		}
+		table->data = data;
+		data->properties_dialog = table->dialog;
+		g_object_add_weak_pointer (G_OBJECT (table->dialog), (gpointer *)&table->data->properties_dialog);
+
+		table->node = gbf_tree_data_get_node (data);
+		update_properties (table);
+	}
+
+	if (path != NULL) gtk_tree_path_free (path);
+}
+
+static GtkWidget *
+pm_project_create_properties_dialog (AnjutaPmProject *project, GtkWindow *parent, GbfProjectView *view, GbfTreeData *data, GtkTreeIter *selected)
+{
+	PropertiesTable *table;
+	GtkWidget *dialog = NULL;
+	GtkBuilder *bxml;
+	GtkWidget *node_view;
+	
+	g_return_val_if_fail (data != NULL, NULL);
+	
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return NULL;
+
+	table = g_new0 (PropertiesTable, 1);
+	table->data = data;
+	table->node = gbf_tree_data_get_node (data);
+	table->project = project;
+	anjuta_util_builder_get_objects (bxml,
+									"properties", &table->table,
+									"head_table", &table->head,
+	                                "nodes_view", &node_view,
+									"main_table", &table->main,
+									"extra_table", &table->extra,
+									"extra_expand", &table->expand,
+									NULL);
+	g_object_ref (table->table);
+	g_object_unref (bxml);
+
+	/* Add tree view */
+	setup_nodes_treeview (gbf_project_view_get_model (view),
+							node_view,
+							is_project_node_but_shortcut,
+							NULL,
+							selected);
+	gtk_widget_show (node_view);
+
+	dialog = gtk_dialog_new_with_buttons (NULL,
+						   parent,
+						   GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_STOCK_CANCEL,
+						   GTK_RESPONSE_CANCEL,
+						   GTK_STOCK_APPLY,
+						   GTK_RESPONSE_APPLY, NULL);
+	table->dialog = dialog;
+
+	update_properties (table);
+	
+	g_signal_connect (node_view, "cursor-changed",
+					G_CALLBACK (on_node_changed),
+					table);
+	
+	g_signal_connect (dialog, "response",
+					G_CALLBACK (on_properties_dialog_response),
+					table);
+
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))),
+					table->table);
+	gtk_window_set_default_size (GTK_WINDOW (dialog), 450, -1);
+	gtk_widget_show (dialog);
+	
+	return dialog;
+}
+
+
 /* Properties dialog
  *---------------------------------------------------------------------------*/
 
-GtkWidget *
-pm_project_create_properties_dialog (AnjutaPmProject *project, GtkWindow *parent, AnjutaProjectNode *node)
+/* Display properties dialog. These dialogs are not modal, so a pointer on each
+ * dialog is kept with in node data to be able to destroy them if the node is
+ * removed. It is useful to put the dialog at the top if the same target is
+ * selected while the corresponding dialog already exist instead of creating
+ * two times the same dialog.
+ * The project properties dialog is display if the node iterator is NULL. */
+
+gboolean
+anjuta_pm_project_show_properties_dialog (ProjectManagerPlugin *plugin, GtkTreeIter *selected)
 {
-	const char *title;
-	PropertiesTable *table;
-	GtkWidget *dialog = NULL;
-
-	g_return_val_if_fail (node != NULL, NULL);
+	GtkWidget **dialog_ptr;
+	GtkTreeIter iter;
 	
-	switch (anjuta_project_node_get_node_type (node))
+	if (selected == NULL)
 	{
-	case ANJUTA_PROJECT_ROOT:
-		title = _("Project properties");
-		break;
-	case ANJUTA_PROJECT_GROUP:
-		title = _("Group properties");
-		break;
-	case ANJUTA_PROJECT_TARGET:
-		title = _("Target properties");
-		break;
-	case ANJUTA_PROJECT_SOURCE:
-		title = _("Source properties");
-		break;
-	case ANJUTA_PROJECT_MODULE:
-		title = _("Module properties");
-		break;
-	case ANJUTA_PROJECT_PACKAGE:
-		title = _("Package properties");
-		break;
-	default:
-		return NULL;
+		/* Display root properties by default */
+		if (gbf_project_view_get_project_root (plugin->view, &iter))
+		{
+			selected = &iter;
+		}
 	}
 
-	table = create_properties_table (project->project, node);
-
-	if (table != NULL)
+	if (selected)
 	{
-		table->project = project;
-		dialog = gtk_dialog_new_with_buttons (title,
-							   parent,
-							   GTK_DIALOG_DESTROY_WITH_PARENT,
-							   GTK_STOCK_CANCEL,
-							   GTK_RESPONSE_CANCEL,
-							   GTK_STOCK_APPLY,
-							   GTK_RESPONSE_APPLY, NULL);
+		GbfTreeData *data;
+		
+		gtk_tree_model_get (GTK_TREE_MODEL (gbf_project_view_get_model (plugin->view)), selected, GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
 
-		g_signal_connect (dialog, "response",
-						G_CALLBACK (on_properties_dialog_response),
-						table);
-
-		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))),
-				table->table);
-		gtk_window_set_default_size (GTK_WINDOW (dialog), 450, -1);
-		gtk_widget_show (dialog);
+		dialog_ptr = &data->properties_dialog;
+	
+		if (*dialog_ptr != NULL)
+		{
+			/* Show already existing dialog */
+			gtk_window_present (GTK_WINDOW (*dialog_ptr));
+		}
+		else
+		{
+			*dialog_ptr = pm_project_create_properties_dialog (
+				plugin->project,
+				GTK_WINDOW (plugin->project->plugin->shell),
+			    plugin->view,
+			    data,                                               
+				selected);
+			if (*dialog_ptr != NULL)
+			{
+				g_object_add_weak_pointer (G_OBJECT (*dialog_ptr), (gpointer *)dialog_ptr);
+			}
+		}
 	}
 
-	return dialog;
+	return selected != NULL;
 }
 
+
+
 /* Group dialog
  *---------------------------------------------------------------------------*/
 
 AnjutaProjectNode*
-anjuta_pm_project_new_group (AnjutaPmProject *project, GtkWindow *parent, GtkTreeIter *selected, const gchar *default_name)
+anjuta_pm_project_new_group (ProjectManagerPlugin *plugin, GtkWindow *parent, GtkTreeIter *selected, const gchar *default_name)
 {
 	GtkBuilder *gui;
 	GtkWidget *dialog, *group_name_entry, *ok_button;
@@ -738,7 +904,7 @@ anjuta_pm_project_new_group (AnjutaPmProject *project, GtkWindow *parent, GtkTre
 	gboolean finished = FALSE;
 	AnjutaProjectNode *new_group = NULL;
 
-	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (plugin->project != NULL, NULL);
 
 	gui = load_interface ("new_group_dialog");
 	g_return_val_if_fail (gui != NULL, NULL);
@@ -760,7 +926,7 @@ anjuta_pm_project_new_group (AnjutaPmProject *project, GtkWindow *parent, GtkTre
 	else
 		gtk_widget_set_sensitive (ok_button, FALSE);
 
-	setup_nodes_treeview (anjuta_pm_project_get_model (project),
+	setup_nodes_treeview (gbf_project_view_get_model (plugin->view),
 							groups_view,
 							parent_filter_func,
 							GINT_TO_POINTER (ANJUTA_PROJECT_GROUP),
@@ -791,7 +957,7 @@ anjuta_pm_project_new_group (AnjutaPmProject *project, GtkWindow *parent, GtkTre
 														ANJUTA_PROJECT_GROUP);
 				if (group)
 				{
-					new_group = anjuta_pm_project_add_group (project, group, NULL, name, &err);
+					new_group = anjuta_pm_project_add_group (plugin->project, group, NULL, name, &err);
 					if (err)
 					{
 						error_dialog (parent, _("Cannot add group"), "%s",
@@ -828,7 +994,7 @@ anjuta_pm_project_new_group (AnjutaPmProject *project, GtkWindow *parent, GtkTre
  *---------------------------------------------------------------------------*/
 
 AnjutaProjectNode*
-anjuta_pm_project_new_source (AnjutaPmProject *project,
+anjuta_pm_project_new_source (ProjectManagerPlugin *plugin,
 							GtkWindow           *parent,
 							GtkTreeIter         *default_parent,
 							const gchar         *default_uri)
@@ -843,7 +1009,7 @@ anjuta_pm_project_new_source (AnjutaPmProject *project,
 		uris = g_list_append (NULL, uri);
 	}
 	new_sources = 
-		anjuta_pm_project_new_multiple_source (project, parent,
+		anjuta_pm_project_new_multiple_source (plugin, parent,
 										default_parent, uris);
 	g_free (uri);
 	g_list_free (uris);
@@ -859,7 +1025,7 @@ anjuta_pm_project_new_source (AnjutaPmProject *project,
 }
 
 GList* 
-anjuta_pm_project_new_multiple_source (AnjutaPmProject *project,
+anjuta_pm_project_new_multiple_source (ProjectManagerPlugin *plugin,
 								GtkWindow           *top_window,
 								GtkTreeIter         *default_parent,
 								GList               *uris_to_add)
@@ -876,7 +1042,7 @@ anjuta_pm_project_new_multiple_source (AnjutaPmProject *project,
 	GList* new_sources = NULL;
 	GList* uri_node;
 
-	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (plugin->project != NULL, NULL);
 
 	gui = load_interface ("add_source_dialog");
 	g_return_val_if_fail (gui != NULL, NULL);
@@ -932,7 +1098,7 @@ anjuta_pm_project_new_multiple_source (AnjutaPmProject *project,
 	/*project_root = g_file_get_uri (anjuta_project_node_get_file (anjuta_pm_project_get_root (project)));
 	g_object_set_data_full (G_OBJECT (browse_button), "root", project_root, g_free);*/
 
-	setup_nodes_treeview (anjuta_pm_project_get_model (project),
+	setup_nodes_treeview (gbf_project_view_get_model (plugin->view),
 							targets_view,
 							parent_filter_func,
 							GINT_TO_POINTER (ANJUTA_PROJECT_SOURCE),
@@ -993,7 +1159,7 @@ anjuta_pm_project_new_multiple_source (AnjutaPmProject *project,
 					gtk_tree_model_get (GTK_TREE_MODEL(list), &iter,
 						COLUMN_URI, &uri, -1);
 
-					new_source = anjuta_pm_project_add_source (project,
+					new_source = anjuta_pm_project_add_source (plugin->project,
 									parent,
 									sibling,
 									uri,
@@ -1101,7 +1267,7 @@ build_types_store (AnjutaPmProject *project)
 }
 
 AnjutaProjectNode* 
-anjuta_pm_project_new_target (AnjutaPmProject *project,
+anjuta_pm_project_new_target (ProjectManagerPlugin *plugin,
                              GtkWindow       *parent,
                              GtkTreeIter     *default_group,
                              const gchar     *default_target_name_to_add)
@@ -1115,7 +1281,7 @@ anjuta_pm_project_new_target (AnjutaPmProject *project,
 	gboolean finished = FALSE;
 	AnjutaProjectNode *new_target = NULL;
 
-	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (plugin->project != NULL, NULL);
 
 	gui = load_interface ("new_target_dialog");
 	g_return_val_if_fail (gui != NULL, NULL);
@@ -1138,7 +1304,7 @@ anjuta_pm_project_new_target (AnjutaPmProject *project,
 	else
 		gtk_widget_set_sensitive (ok_button, FALSE);
 
-	setup_nodes_treeview (anjuta_pm_project_get_model (project),
+	setup_nodes_treeview (gbf_project_view_get_model (plugin->view),
 							groups_view,
 							parent_filter_func,
 							GINT_TO_POINTER (ANJUTA_PROJECT_TARGET),
@@ -1146,7 +1312,7 @@ anjuta_pm_project_new_target (AnjutaPmProject *project,
 	gtk_widget_show (groups_view);
 
 	/* setup target types combo box */
-	types_store = build_types_store (project);
+	types_store = build_types_store (plugin->project);
 	gtk_combo_box_set_model (GTK_COMBO_BOX (target_type_combo), 
 							GTK_TREE_MODEL (types_store));
 
@@ -1206,7 +1372,7 @@ anjuta_pm_project_new_target (AnjutaPmProject *project,
 
 				if (group && type)
 				{
-					new_target = anjuta_pm_project_add_target (project, group, NULL, name, type, &err);
+					new_target = anjuta_pm_project_add_target (plugin->project, group, NULL, name, type, &err);
 					if (err)
 					{
 						error_dialog (parent, _("Cannot add target"), "%s",
@@ -1259,7 +1425,7 @@ on_cursor_changed(GtkTreeView* view, gpointer data)
 }
 
 GList*
-anjuta_pm_project_new_module (AnjutaPmProject *project,
+anjuta_pm_project_new_module (ProjectManagerPlugin *plugin,
                              GtkWindow          *parent,
                              GtkTreeIter        *default_target,
                              const gchar        *default_module)
@@ -1274,7 +1440,7 @@ anjuta_pm_project_new_module (AnjutaPmProject *project,
 	GList* new_modules = NULL;
 	GtkTreeSelection *module_selection;
 
-	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (plugin->project != NULL, NULL);
 
 	gui = load_interface ("add_module_dialog");
 	g_return_val_if_fail (gui != NULL, NULL);
@@ -1286,13 +1452,13 @@ anjuta_pm_project_new_module (AnjutaPmProject *project,
 	new_button = GTK_WIDGET (gtk_builder_get_object (gui, "new_package_button"));
 	ok_button = GTK_WIDGET (gtk_builder_get_object (gui, "ok_module_button"));
 
-	setup_nodes_treeview (anjuta_pm_project_get_model (project),
+	setup_nodes_treeview (gbf_project_view_get_model (plugin->view),
 							targets_view,
 							parent_filter_func,
 							GINT_TO_POINTER (ANJUTA_PROJECT_MODULE),
 							default_target);
 	gtk_widget_show (targets_view);
-	setup_nodes_treeview (anjuta_pm_project_get_model (project),
+	setup_nodes_treeview (gbf_project_view_get_model (plugin->view),
 							modules_view,
 							module_filter_func,
 							NULL,
@@ -1331,7 +1497,7 @@ anjuta_pm_project_new_module (AnjutaPmProject *project,
 		switch (response) {
 			case 1:
 			{
-				anjuta_pm_project_new_package (project, parent, NULL, NULL);
+				anjuta_pm_project_new_package (plugin, parent, NULL, NULL);
 
 				break;
 			}
@@ -1357,7 +1523,7 @@ anjuta_pm_project_new_module (AnjutaPmProject *project,
 						new_module = gbf_tree_data_get_node (node->data);
 						name = anjuta_project_node_get_name (new_module);
 
-						new_module = ianjuta_project_add_node_after (project->project, target, NULL, ANJUTA_PROJECT_MODULE, NULL, name, &error);
+						new_module = ianjuta_project_add_node_after (plugin->project->project, target, NULL, ANJUTA_PROJECT_MODULE, NULL, name, &error);
 						if (error) {
 							gchar *str = g_strdup_printf ("%s: %s\n",
 															name,
@@ -1472,7 +1638,7 @@ on_pkg_chooser_selection_changed (AnjutaPkgConfigChooser* chooser,
 }
 
 GList* 
-anjuta_pm_project_new_package (AnjutaPmProject *project,
+anjuta_pm_project_new_package (ProjectManagerPlugin *plugin,
                               GtkWindow        *parent,
                               GtkTreeIter      *default_module,
                               GList            *packages_to_add)
@@ -1492,7 +1658,7 @@ anjuta_pm_project_new_package (AnjutaPmProject *project,
     gint default_pos = -1;
 	gint pos;
     
-    g_return_val_if_fail (project != NULL, NULL);
+    g_return_val_if_fail (plugin->project != NULL, NULL);
     
     gui = load_interface ("add_package_dialog");
     g_return_val_if_fail (gui != NULL, NULL);
@@ -1509,7 +1675,7 @@ anjuta_pm_project_new_package (AnjutaPmProject *project,
         GbfTreeData *data;
 	    GbfProjectModel *model;
 
-		model = anjuta_pm_project_get_model(project);
+		model = gbf_project_view_get_model(plugin->view);
 		gtk_tree_model_get (GTK_TREE_MODEL (model), default_module, GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
 		if (data != NULL)
 		{
@@ -1521,7 +1687,7 @@ anjuta_pm_project_new_package (AnjutaPmProject *project,
     store = gtk_list_store_new(1, G_TYPE_STRING);	
     gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (module_entry), 0);
 
-	root = ianjuta_project_get_root (project->project, NULL);
+	root = ianjuta_project_get_root (plugin->project->project, NULL);
 	pos = 0;
 	for (node = anjuta_project_node_first_child (root); node != NULL; node = anjuta_project_node_next_sibling (node))
 	{
@@ -1593,16 +1759,16 @@ anjuta_pm_project_new_package (AnjutaPmProject *project,
 				else
 				{
 					/* Look for already existing module */
-					module = anjuta_pm_project_get_module (project, name);
+					module = anjuta_pm_project_get_module (plugin->project, name);
 					if (module == NULL)
 					{
 						/* Create new module */
 						AnjutaProjectNode *root;
 						GError *error = NULL;
 
-						root = ianjuta_project_get_root (project->project, NULL);
+						root = ianjuta_project_get_root (plugin->project->project, NULL);
 
-						module = ianjuta_project_add_node_after (project->project, root, NULL, ANJUTA_PROJECT_MODULE, NULL, name, &error);
+						module = ianjuta_project_add_node_after (plugin->project->project, root, NULL, ANJUTA_PROJECT_MODULE, NULL, name, &error);
 						if (error != NULL)
 						{
                     		gchar *str = g_strdup_printf ("%s: %s\n", name, error->message);
@@ -1629,7 +1795,7 @@ anjuta_pm_project_new_package (AnjutaPmProject *project,
 
 						name = node->data;
 
-						new_package = ianjuta_project_add_node_after (project->project, module, NULL, ANJUTA_PROJECT_PACKAGE, NULL, name, &error);
+						new_package = ianjuta_project_add_node_after (plugin->project->project, module, NULL, ANJUTA_PROJECT_PACKAGE, NULL, name, &error);
 						if (error)
 						{
 							gchar *str = g_strdup_printf ("%s: %s\n",
