@@ -57,10 +57,13 @@ struct _SvnRemoveCommand
 };
 
 GType svn_remove_command_get_type (void) G_GNUC_CONST;
-SvnRemoveCommand * svn_remove_command_new (const gchar *path, const gchar *log_message, 
-										   gboolean force);
+SvnRemoveCommand *svn_remove_command_new_path (const gchar *path, 
+											   const gchar *log_message, 
+											   gboolean force);
+SvnRemoveCommand *svn_remove_command_new_list (GList *paths, 
+											   const gchar *log_message,
+											   gboolean force);
 void svn_remove_command_destroy (SvnRemoveCommand *self);
-gchar *svn_remove_command_get_path (SvnRemoveCommand *self);
 
 G_END_DECLS
 
