@@ -62,6 +62,7 @@ struct _SymbolDBQueryPriv {
 
 	SymbolDBEngine *dbe_system;
 	SymbolDBEngine *dbe_project;
+	/* a reference to dbe_system or dbe_project */
 	SymbolDBEngine *dbe_selected;
 	
 	/* Param holders */
@@ -509,6 +510,7 @@ sdb_query_execute_real (SymbolDBQuery *query)
 	data_model = symbol_db_engine_execute_select (priv->dbe_selected,
 	                                              priv->stmt,
 	                                              priv->params);
+	
 	if (!data_model) return GINT_TO_POINTER (-1);
 	return symbol_db_query_result_new (data_model, 
 	                                   priv->fields,
@@ -526,15 +528,16 @@ sdb_query_handle_result (SymbolDBQuery *query, SymbolDBQueryResult *result)
 	}
 	else
 	{
-		if (result == NULL || symbol_db_query_result_is_empty (result))
+		if (symbol_db_query_result_is_empty (result))
 		{
 			g_signal_emit_by_name (query, "async-result", NULL);
 		}
 		else
 		{			
-			g_signal_emit_by_name (query, "async-result", result);
-			g_object_unref (result);
+			g_signal_emit_by_name (query, "async-result", result);			
 		}
+		if (result)
+			g_object_unref (result);
 	}
 }
 
@@ -762,7 +765,7 @@ sdb_query_dispose (GObject *object)
 		g_signal_handlers_disconnect_by_func (priv->dbe_selected,
 		                                      on_sdb_query_dbe_disconnected,
 		                                      object);
-		g_object_unref (priv->dbe_selected);
+		/* no need to unref dbe_selected */
 		priv->dbe_selected = NULL;
 	}
 	if (priv->dbe_system)
@@ -787,7 +790,7 @@ sdb_query_dispose (GObject *object)
 	}
 	if (priv->async_result_queue)
 	{
-		g_object_unref (priv->async_result_queue);
+		g_async_queue_unref (priv->async_result_queue);
 		priv->async_result_queue = NULL;
 	}
 	if (priv->async_poll_id)
@@ -870,7 +873,9 @@ sdb_query_set_property (GObject *object, guint prop_id, const GValue *value, GPa
 				priv->dbe_selected = priv->dbe_system;
 				break;
 		}
-		g_object_ref (priv->dbe_selected);
+		g_object_ref (priv->dbe_project);
+		g_object_ref (priv->dbe_system);
+			
 		g_signal_connect (priv->dbe_selected, "scan-end",
 		                  G_CALLBACK (on_sdb_query_dbe_scan_end), query);
 		g_signal_connect (priv->dbe_selected, "db-connected",
